@@ -91,9 +91,7 @@ int32_t SPVM__Net__SSLeay__connect(SPVM_ENV* env, SPVM_VALUE* stack) {
     env->set_field_int_by_name(env, stack, obj_self, "operation_error", ssl_operation_error, &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
     
-    int64_t ssl_error = ERR_get_error();
-    env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-    if (error_id) { return error_id; }
+    int64_t ssl_error = ERR_peek_last_error();
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
@@ -122,9 +120,7 @@ int32_t SPVM__Net__SSLeay__accept(SPVM_ENV* env, SPVM_VALUE* stack) {
     env->set_field_int_by_name(env, stack, obj_self, "operation_error", ssl_operation_error, &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
     
-    int64_t ssl_error = ERR_get_error();
-    env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-    if (error_id) { return error_id; }
+    int64_t ssl_error = ERR_peek_last_error();
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
@@ -154,9 +150,7 @@ int32_t SPVM__Net__SSLeay__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
     
     assert(ssl_operation_error != SSL_ERROR_NONE);
     
-    int64_t ssl_error = ERR_get_error();
-    env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-    if (error_id) { return error_id; }
+    int64_t ssl_error = ERR_peek_last_error();
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
@@ -184,9 +178,7 @@ int32_t SPVM__Net__SSLeay__set_fd(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = SSL_set_fd(ssl, fd);
   
   if (!(status == 1)) {
-    int64_t ssl_error = ERR_get_error();
-    env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-    if (error_id) { return error_id; }
+    int64_t ssl_error = ERR_peek_last_error();
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
@@ -218,9 +210,7 @@ int32_t SPVM__Net__SSLeay__set_tlsext_host_name(SPVM_ENV* env, SPVM_VALUE* stack
   int32_t status = SSL_set_tlsext_host_name(ssl, name);
   
   if (!(status == 1)) {
-    int64_t ssl_error = ERR_get_error();
-    env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-    if (error_id) { return error_id; }
+    int64_t ssl_error = ERR_peek_last_error();
     
     char ssl_error_string[256] = {0};
     ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
@@ -275,9 +265,7 @@ int32_t SPVM__Net__SSLeay__read(SPVM_ENV* env, SPVM_VALUE* stack) {
       env->set_field_int_by_name(env, stack, obj_self, "operation_error", ssl_operation_error, &error_id, __func__, FILE_NAME, __LINE__);
       if (error_id) { return error_id; }
       
-      int64_t ssl_error = ERR_get_error();
-      env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-      if (error_id) { return error_id; }
+      int64_t ssl_error = ERR_peek_last_error();
       
       char ssl_error_string[256] = {0};
       ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
@@ -334,9 +322,7 @@ int32_t SPVM__Net__SSLeay__peek(SPVM_ENV* env, SPVM_VALUE* stack) {
       env->set_field_int_by_name(env, stack, obj_self, "operation_error", ssl_operation_error, &error_id, __func__, FILE_NAME, __LINE__);
       if (error_id) { return error_id; }
       
-      int64_t ssl_error = ERR_get_error();
-      env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-      if (error_id) { return error_id; }
+      int64_t ssl_error = ERR_peek_last_error();
       
       char ssl_error_string[256] = {0};
       ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
@@ -393,9 +379,7 @@ int32_t SPVM__Net__SSLeay__write(SPVM_ENV* env, SPVM_VALUE* stack) {
       env->set_field_int_by_name(env, stack, obj_self, "operation_error", ssl_operation_error, &error_id, __func__, FILE_NAME, __LINE__);
       if (error_id) { return error_id; }
       
-      int64_t ssl_error = ERR_get_error();
-      env->set_field_long_by_name(env, stack, obj_self, "error", ssl_error, &error_id, __func__, FILE_NAME, __LINE__);
-      if (error_id) { return error_id; }
+      int64_t ssl_error = ERR_peek_last_error();
       
       char ssl_error_string[256] = {0};
       ERR_error_string_n(ssl_error, ssl_error_string, sizeof(ssl_error_string));
