@@ -110,7 +110,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_default_verify_paths(SPVM_ENV* env, SPVM
   int32_t status = SSL_CTX_set_default_verify_paths(ssl_ctx);
   
   if (!(status == 1)) {
-    env->die(env, stack, "[System Error]SSL_CTX_set_default_verify_paths failed.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "SSL_CTX_set_default_verify_paths failed.", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -128,7 +128,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_certificate_file(SPVM_ENV* env, SPVM_VAL
   void* obj_file = stack[1].oval;
   
   if (!obj_file) {
-    return env->die(env, stack, "The $file must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file $file must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* file = (char*)env->get_chars(env, stack, obj_file);
@@ -141,7 +141,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_certificate_file(SPVM_ENV* env, SPVM_VAL
   int32_t status = SSL_CTX_use_certificate_file(ssl_ctx, file, type);
   
   if (!(status == 1)) {
-    env->die(env, stack, "[System Error]SSL_CTX_use_certificate_file failed.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "SSL_CTX_use_certificate_file failed.", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -159,7 +159,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_certificate_chain_file(SPVM_ENV* env, SP
   void* obj_file = stack[1].oval;
   
   if (!obj_file) {
-    return env->die(env, stack, "The $file must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file $file must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* file = (char*)env->get_chars(env, stack, obj_file);
@@ -170,7 +170,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_certificate_chain_file(SPVM_ENV* env, SP
   int32_t status = SSL_CTX_use_certificate_chain_file(ssl_ctx, file);
   
   if (!(status == 1)) {
-    env->die(env, stack, "[System Error]SSL_CTX_use_certificate_chain_file failed.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "SSL_CTX_use_certificate_chain_file failed.", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -188,7 +188,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_PrivateKey_file(SPVM_ENV* env, SPVM_VALU
   void* obj_file = stack[1].oval;
   
   if (!obj_file) {
-    return env->die(env, stack, "The $file must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file $file must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* file = (char*)env->get_chars(env, stack, obj_file);
@@ -201,7 +201,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__use_PrivateKey_file(SPVM_ENV* env, SPVM_VALU
   int32_t status = SSL_CTX_use_PrivateKey_file(ssl_ctx, file, type);
   
   if (!(status == 1)) {
-    env->die(env, stack, "[System Error]SSL_CTX_use_PrivateKey_file failed.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "SSL_CTX_use_PrivateKey_file failed.", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -219,7 +219,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_cipher_list(SPVM_ENV* env, SPVM_VALUE* s
   void* obj_str = stack[1].oval;
   
   if (!obj_str) {
-    return env->die(env, stack, "The $str must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The cipher list $str must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* str = (char*)env->get_chars(env, stack, obj_str);
@@ -232,7 +232,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_cipher_list(SPVM_ENV* env, SPVM_VALUE* s
   int32_t status = SSL_CTX_set_cipher_list(ssl_ctx, str);
   
   if (!(status == 1)) {
-    env->die(env, stack, "[System Error]SSL_CTX_set_cipher_list failed.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "SSL_CTX_set_cipher_list failed.", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -253,7 +253,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_ciphersuites(SPVM_ENV* env, SPVM_VALUE*
   void* obj_str = stack[1].oval;
   
   if (!obj_str) {
-    return env->die(env, stack, "The $str must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The ciphersuites $str must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   char* str = (char*)env->get_chars(env, stack, obj_str);
@@ -266,7 +266,7 @@ int32_t SPVM__Net__SSLeay__SSL_CTX__set_ciphersuites(SPVM_ENV* env, SPVM_VALUE*
   int32_t status = SSL_CTX_set_ciphersuites(ssl_ctx, str);
   
   if (!(status == 1)) {
-    env->die(env, stack, "[System Error]SSL_CTX_set_ciphersuites failed.", __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "SSL_CTX_set_ciphersuites failed.", __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
