@@ -6,11 +6,11 @@ package SPVM::Net::SSLeay::X509_STORE_CTX;
 
 =head1 Name
 
-SPVM::Net::SSLeay::X509_STORE_CTX - X509_STORE_CTX
+SPVM::Net::SSLeay::X509_STORE_CTX - X509_STORE_CTX data structure
 
 =head1 Description
 
-Net::SSLeay::X509_STORE_CTX class in L<SPVM> represents C<X509_STORE_CTX> structure in OpenSSL.
+Net::SSLeay::X509_STORE_CTX class in L<SPVM> represents L<X509_STORE_CTX|https://docs.openssl.org/3.1/man3/X509_STORE_CTX_new/> structure in OpenSSL.
 
 =head1 Usage
 
